.. _ramp_fitting_step:

============
Ramp Fitting
============

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. toctree::
   :maxdepth: 1

   description_ols.rst


.. automodapi:: romancal.ramp_fitting
